@@ -1,7 +1,6 @@
-from django.contrib.auth import get_user_model
-from rest_framework import serializers
 # from rest_framework.serializers import Serializer
-from primary_key import reverse_id
+from reversable_primary_key.primary_key import reverse_id
+from rest_framework import serializers
 
 
 class CreatedSerializerMixin(serializers.Serializer):
@@ -11,4 +10,5 @@ class CreatedSerializerMixin(serializers.Serializer):
         try:
             return reverse_id(obj.id)
         except Exception:
-            return None
\ No newline at end of file
+            return None
+
